"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLambdaFunction = void 0;
const fs = require("fs");
const child_process_1 = require("child_process");
const taquito_1 = require("@taquito/taquito");
const lambdaFunctionLibrary_1 = require("./lambdaFunctionLibrary");
const packLambdaFunction = async (tezos, governanceProxyContractAddress, lambdaFunction) => {
    const governanceProxyInstance = await tezos.contract.at(governanceProxyContractAddress);
    const param = governanceProxyInstance.methods.dataPackingHelper(lambdaFunction).toTransferParams();
    if (param.parameter) {
        const paramValue = param.parameter.value;
        const lambdaEntrypointType = await governanceProxyInstance.entrypoints.entrypoints.dataPackingHelper;
        const packed = await tezos.rpc.packData({
            data: paramValue,
            type: lambdaEntrypointType
        }).catch(e => console.error('error:', e));
        var packedParam;
        if (packed) {
            packedParam = packed.packed;
        }
        else {
            throw `packing failed`;
        }
        ;
    }
    return packedParam;
};
function getLigo(isDockerizedLigo, ligoVersion = "0.60.0") {
    let path = 'ligo';
    if (isDockerizedLigo) {
        path = `docker run --platform=linux/amd64 -v $PWD:$PWD --rm -i ligolang/ligo:${ligoVersion}`;
        try {
            (0, child_process_1.execSync)(`${path}  --help`);
        }
        catch (err) {
            path = 'ligo';
            (0, child_process_1.execSync)(`${path}  --help`);
        }
    }
    else {
        try {
            (0, child_process_1.execSync)(`${path}  --help`);
        }
        catch (err) {
            path = `docker run --platform=linux/amd64 -v $PWD:$PWD --rm -i ligolang/ligo:${ligoVersion}`;
            (0, child_process_1.execSync)(`${path}  --help`);
        }
    }
    return path;
}
const compileLambdaFunctionContract = async (contractPath = "", ligoVersion = "0.60.0") => {
    const ligo = getLigo(true, ligoVersion);
    const jsonFormat = (0, child_process_1.execSync)(`${ligo} compile contract ${contractPath} --michelson-format json --protocol lima`, {
        maxBuffer: 1024 * 1024,
        timeout: 1024 * 1024
    }).toString();
    // Get the lambda function from the compiled code
    return JSON.parse(jsonFormat)[2].args[0][1].args[0];
};
const getLambdaFunction = async (rpc, governanceProxyContractAddress, lambdaFunctionName, lambdaFunctionParameters = []) => {
    // Read the contents of the input file specified in the first command line argument
    const generatedContract = (0, lambdaFunctionLibrary_1.generateProxyContract)(lambdaFunctionName, lambdaFunctionParameters);
    // Write the result to the output file
    const outputFile = __dirname + "/governanceProxyLambdaFunction.ligo";
    fs.writeFileSync(outputFile, generatedContract);
    // Start the compiling process
    const lambdaFunctionJson = await compileLambdaFunctionContract(outputFile);
    const tezos = new taquito_1.TezosToolkit(rpc);
    const packedLambdaFunction = await packLambdaFunction(tezos, governanceProxyContractAddress, lambdaFunctionJson);
    return packedLambdaFunction;
};
exports.getLambdaFunction = getLambdaFunction;
//# sourceMappingURL=lambdaFunctionPacker.service.js.map